globalVariables(c("binomial", ".data", ".env"))


#' @importFrom generics glance
#' @export
generics::glance

#' @importFrom generics tidy
#' @export
generics::tidy
